@@ -27,6 +27,10 @@
 
 typedef std::vector<std::string> StringVector;
 
+std::string trimSpaces(std::string str);
+std::string trimSet(std::string str, std::string trimset);
+std::string replaceAll(std::string str, std::string from, std::string to);
+
 const std::string stringtf( const char *format, ... );
 const std::string stringtf( const std::string &format, ... );
 
