@@ -132,6 +132,7 @@ $SLANG = array(
     'BadFPSReportInterval'  => 'FPS帧数报告间隔缓冲数必须是0以上整数',
     'BadFormat'             => '格式必须设为大于零的整数',
     'BadFrameSkip'          => '跳帧数必须设为大于零的整数',
+    'BadMotionFrameSkip'    => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'             => '高度必须设为有效值',
     'BadHost'               => '主机必须设为有效IP地址或主机名，不要包含 http://',
     'BadImageBufferCount'   => '图像缓冲器大小必须设为大于10的整数',
@@ -152,6 +153,7 @@ $SLANG = array(
     'BadWebColour'          => 'Web颜色必须设为有效Web颜色字符',
     'BadWidth'              => '宽度必须设为有效值',
     'Bandwidth'             => '带宽',
+    'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'                => 'Blob像素',
     'BlobSizes'             => 'Blob大小',
     'Blobs'                 => 'Blobs',
@@ -320,6 +322,12 @@ $SLANG = array(
     'First'                 => '首先',
     'FlippedHori'           => '水平翻转',
     'FlippedVert'           => '垂直翻转',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                 => '聚焦',
     'ForceAlarm'            => '强制报警',
     'Format'                => '格式',
@@ -327,6 +335,7 @@ $SLANG = array(
     'FrameId'               => '帧 Id',
     'FrameRate'             => '帧率',
     'FrameSkip'             => '跳帧',
+    'MotionFrameSkip'       => 'Motion Frame Skip',
     'Frames'                => '帧',
     'Func'                  => '功能',
     'Function'              => '功能',
@@ -370,6 +379,7 @@ $SLANG = array(
     'Last'                  => '最后',
     'Layout'                => '布局',
     'Level'                => 'Level',                  // Added - 2011-06-16
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'      => '个结果', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'       => '仅限于开始', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                 => 'Line',                   // Added - 2011-06-16
@@ -463,6 +473,11 @@ $SLANG = array(
     'Month'                 => '月',
     'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                  => '移动',
+    'MtgDefault'            => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'            => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'            => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'            => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'            => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'              => '必须大于等于',
     'MustBeLe'              => '必须小于等于',
     'MustConfirmPassword'   => '您必须确认密码',
@@ -631,6 +646,10 @@ $SLANG = array(
     'TimeDelta'             => '相对时间',
     'TimeStamp'             => '时间戳',
     'Timeline'              => '时间轴',
+    'TimelineTip1'          => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'          => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'          => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'             => '时间戳',
     'TimestampLabelFormat'  => '时间戳标签格式',
     'TimestampLabelX'       => '时间戳标签 X',
@@ -708,6 +727,7 @@ $SLANG = array(
     'ZoneMinMaxPixelThres'  => '最小/最大像素阈值(0-255)',
     'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'    => '忽略过载帪数',
+    'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'Zones'                 => '区域',
     'Zoom'                  => '缩放',
     'ZoomIn'                => '放大',
@@ -839,6 +859,20 @@ function zmVlang( $langVarArray, $count )
 // These overrides are in the form show below where the array key represents the option name minus the initial ZM_
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
 //        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
