@@ -23,13 +23,9 @@ if ( !canEdit( 'Devices' ) )
     $view = "error";
     return;
 }
-if ( !empty($_REQUEST['did']) )
-{
-    $sql = "select * from Devices where Id = '".dbEscape($_REQUEST['did'])."'";
-    $newDevice = dbFetchOne( $sql );
-}
-else
-{
+if ( !empty($_REQUEST['did']) ) {
+    $newDevice = dbFetchOne( 'SELECT * FROM Devices WHERE Id = ?', NULL, array($_REQUEST['did']) );
+} else {
     $newDevice = array(
         "Id" => "",
         "Name" => "New Device",
